	SUBROUTINE	INSIDE (PHI0, RAM0, PHCNR, RMCNR, N, INDEX)

!	**********************************************************
!	**	INSIDE		88/10/31	ver.2.0		**
!	**			89/02/12	ver.2.1		**
!	**				debugged		**
!	**							**
!	**	 Subroutine for checking whether a earthquake 	**
!	**	is located in a region given			**
!	**							**
!	**	 This version can be used even if the region	**
!	**	has comlex shape so long as the boundary lines	**
!	**	do not cross each other.			**
!	**	 Algorithm of this routine is originally	**
!	**	given by Dr. Y. Kuwahara.			**
!	**							**
!	**		88/10/31	T. Matsuzawa		**
!	**********************************************************

!	------ Input --------
	REAL	PHI0,		! Latitude of the epicenter
	2	RAM0,		! Longitude of the epicenter
	2	PHCNR(10),	! Latitudes of the corners of the region
	2	RMCNR(10)	! Longitude of the corners of the region
	INTEGER	N		! Total number of corners

!	------ Output -------
	INTEGER	INDEX		! = 1 : epicenter is inside of the region
				! = 0 : epicenter is outside of the region

!	------ N > 2 ? ------
	IF (N.LT.2)	RETURN

	IF (N.EQ.2)	THEN	! If N = 2, PHCNR and RMCNR are interpreted
	    INDEX	= 1	! as the limits of lat. and lon. of the region
	    IF (PHCNR(1).GT.PHCNR(2)) THEN
		PHIL 	= PHCNR(2)
		PHIH	= PHCNR(1)
	    ELSE
		PHIL	= PHCNR(1)
		PHIH	= PHCNR(2)
	    ENDIF
	    IF (RMCNR(1).GT.RMCNR(2)) THEN
		RAML	= RMCNR(2)
		RAMH	= RMCNR(1)
	    ELSE
		RAML	= RMCNR(1)
		RAMH	= RMCNR(2)
	    ENDIF
	    IF (PHI0.GT.PHIH .OR. PHI0.LT.PHIL)	INDEX	= 0
	    IF (RAM0.GT.RAMH .OR. RAM0.LT.RAML)	INDEX	= 0 

	ELSE
!	----- N >= 3 ---------------------
!	   A brief explanation of the algorithm used here is as follows:
!	If the epicenter is located inside of the region, longitudal line
!	of the epicenter must cross the boundary of the region odd times
!	north of the epicenter.  Thus all you have to do is count the crossing
!	point north of the epicenter.

	    PHI00	= PHI0
	    RAM00	= RAM0
	    ICROSS	= 0	! Counter 

!	--- If the longitude of the corner of the boundary coinsides with  
!	  that of the epicenter, shift the epicenter a little --------

	    DO I = 1,N
		IF (RMCNR(I).EQ.RAM00) RAM00 = RAM00 + 0.0001
	    ENDDO

	    DO 10 I = 1, N
		J	= I + 1
		IF (J.GT.N)	THEN
		    PHI2	= PHCNR(1)
		    RAM2	= RMCNR(1)
		ELSE
		    PHI2	= PHCNR(J)
		    RAM2	= RMCNR(J)
		ENDIF
		PHI1	= PHCNR(I)
		RAM1	= RMCNR(I)
		IF (PHI1.EQ.PHI0 .AND. RAM1.EQ.RAM0)	GO TO 2000

		IF (PHI1.LT.PHI0 .AND. PHI2.LT.PHI0)	GO TO 10

		IF (RAM2.EQ.RAM0  .AND. RAM1.EQ.RAM0) THEN
		    IF (PHI1.LT.PHI0 .OR. PHI2.LT.PHI0)	GO TO 2000
		ENDIF

		IF (RAM1.LT.RAM00 .AND. RAM2.LT.RAM00)	GO TO 10
		IF (RAM1.GT.RAM00 .AND. RAM2.GT.RAM00)	GO TO 10
		IF (PHI1.EQ.PHI00 .AND. PHI2.EQ.PHI00)	GO TO 2000
		IF (PHI1.GE.PHI00 .AND. PHI2.GE.PHI00)	GO TO 1500

		PHI00X	= (RAM00-RAM1)*(PHI2-PHI1)/(RAM2-RAM1) + PHI1
		IF (PHI00X.LT.PHI00) GO TO 10
1500		CONTINUE
		ICROSS	= ICROSS + 1
10	    CONTINUE
	    INDEX	= MOD(ICROSS,2)
	ENDIF
	RETURN

2000	INDEX	= 1
	RETURN
	END
